<img src=".figs/LANCET_EUROPE_LOGO.png" alt="drawing" width="270"/>  

<div align="justify">

# Indicator 1.3.5: Leishmaniasis (v2024)

## Introduction

The leishmaniases are climate-sensitive zoonotic diseases caused by *Leishmania* protozoan parasites and transmitted by the bites of infectious female sand flies (Diptera: Psychodidae: *Phlebotominae*). Endemic in 99 countries or territories, leishmaniasis disproportionately affects the poorest and marginalised communities, with an estimated 700,000 to 1 million (underreported) new human cases globally every year. In Europe, several sand fly species are known to transmit the parasite, and visceral leishmaniasis is endemic in many southern European countries, with cutaneous leishmaniasis considered an emerging threat. Furthermore, leishmaniasis is considered a climate-sensitive infectious disease, as sand fly species distributions tend to be restricted to warmer areas, although optimum temperature and humidity conditions for sand fly activity vary substantially between species and regions, influencing sand fly metabolism, and the development and survival of the sand fly life stages.

The **Leishmaniasis risk** indicator, published in the Lancet Countdown [Europe](https://lancetcountdown.org/europe/) report, tracks risk for leishmaniasis based one climatic suitablility and socio-economic factors, starting in 1970 until near present time.

## Methods
A machine learning approach was used, building on the work of [Carvalho et al. (2024)](https://www.sciencedirect.com/science/article/pii/S2666776224001388) to predict the risk for *Phlebotomus neglectus*, *P. ariasi*, *P. perfiliewi*, *P. perniciosus*, and *P. tobbi* and visceral and cutaneous leishmaniasis according to climatic suitability and socio-economic risks, in the training period of 1970-2012 for the disease (via data from [Piggott et al., 2014](https://www.nature.com/articles/sdata201436)) and 2015-2024 for the vector (via data from [VectorNet](https://www.ecdc.europa.eu/en/about-us/partnerships-and-networks/disease-and-laboratory-networks/vector-net)). The best fit models in terms of predictive performance were subsequently used to generate annual predictions to NUTS2 for for the full study period (1970-2024). 

#### Data sources

| Variable | Source | Spatial Resolution | Temporal range used | 
| ------ | ------ | ------ | ------ |
| Monthly 2 meter dew point temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Present |
| Monthly 2 meter temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Present |
| Monthly accumulated precipitation | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Present |
| Monthly soil water volume | [ERA5 (monthly)](https://cds.climate.copernicus.eu/datasets/reanalysis-era5-single-levels-monthly-means?tab=overview) | 0.25º x 0.25º | Jan 1940 - Present |
| Land cover | [Copernicus CORINE Land Cover](https://land.copernicus.eu/en/products/corine-land-cover) | 100m | 2019 |
| Altitude | [NASA SRTM](https://www.earthdata.nasa.gov/data/instruments/srtm) | 30m | 2014 |
| Population | [NASA GPW](https://cmr.earthdata.nasa.gov/search/concepts/C1597158029-SEDAC.html) | 1km | 2020 |
| Inequity | [AROPE](https://ec.europa.eu/eurostat/statistics-explained/index.php?title=Glossary:At_risk_of_poverty_or_social_exclusion_(AROPE)) | NUTS2 | 2024 |

Using the raw data, the [WorldClim bioclimatic indciators](https://www.worldclim.org/data/bioclim.html) were calculated and the humidity and soil water data transformed in a similar way (e.g., annual mean, mean in driest, mean in warmest, mean in coldest, mean in wettest quarters). 

## How to read this folder

* [01_data_processing](01_data_processing): 
    * Import and transform climate variables
    * Compute relative humidity
    * Compute bioclimatic indicators
* [02_data_harmonisation](02_data_harmonisation):
    * Harmonise data to one file for fitting
    * Match spatial data
    * Calculate national averages 
* [03_model_fitting](03_model_fitting):
    * Fit prelinmary models to identify feature subset and correlations 
    * Identify best fit models
    * Complete model tuning
* [04_model_predictions](04_model_predictions):
    * Create the predictions dataset
    * Make predcitions with boostrap 
* [05_post_processing](05_post_processing): 
    * Compute spatial and temporal averages
    * Plot results

## Authors
##### - [Gina E C Charnley, PhD](https://www.bsc.es/charnley-georgina-eva-ceres)
##### - [Adria San Jose Plana, PhD](https://www.bsc.es/san-jose-plana-adria)
##### - Carla Maia, PhD 
##### - Orin Courtenay, PhD
##### - [Prof. Rachel Lowe](https://www.bsc.es/lowe-rachel)

##### Contact: georgina.charnley@bsc.es
